@@ -250,7 +250,7 @@ func TestRunPipe(t *testing.T) {
 	}
 	require.NoError(t, Pipe{}.Run(ctx))
 	packages := ctx.Artifacts.Filter(artifact.ByType(artifact.LinuxPackage)).List()
-	require.Len(t, packages, 51)
+	require.Len(t, packages, 47)
 	for _, pkg := range packages {
 		format := pkg.Format()
 		require.NotEmpty(t, format)
@@ -557,6 +557,12 @@ func TestInvalidTemplate(t *testing.T) {
 		testlib.RequireTemplateError(t, Pipe{}.Run(ctx))
 	})
 
+	t.Run("apk key name", func(t *testing.T) {
+		ctx := makeCtx()
+		ctx.Config.NFPMs[0].APK.Signature.KeyName = "{{ .NOPE_KEY_FILE }}"
+		testlib.RequireTemplateError(t, Pipe{}.Run(ctx))
+	})
+
 	t.Run("bindir", func(t *testing.T) {
 		ctx := makeCtx()
 		ctx.Config.NFPMs[0].Bindir = "/usr/{{ .NOPE }}"
