@@ -219,8 +219,8 @@ func signone(ctx *context.Context, cfg config.Sign, art *artifact.Artifact) ([]*
 	cmd := exec.CommandContext(ctx, cfg.Cmd, args...)
 	var b bytes.Buffer
 	w := gio.Safe(&b)
-	cmd.Stderr = io.MultiWriter(logext.NewConditionalWriter(fields, logext.Error, cfg.Output), w)
-	cmd.Stdout = io.MultiWriter(logext.NewConditionalWriter(fields, logext.Info, cfg.Output), w)
+	cmd.Stderr = io.MultiWriter(logext.NewConditionalWriter(cfg.Output), w)
+	cmd.Stdout = io.MultiWriter(logext.NewConditionalWriter(cfg.Output), w)
 	if stdin != nil {
 		cmd.Stdin = stdin
 	}
